#
# spec file for package python-azure-common
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-azure-common
VCS: https://src.suse.de/SLFO-pool/python-azure-common#7a6f02e468e81f155c07695dc41661a609cffd1448498431d088472f38c82cd9
Version:        1.1.28
Release:        160000.1.8
Summary:        Microsoft Azure common code
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/Azure/azure-sdk-for-python
Source:         https://files.pythonhosted.org/packages/source/a/azure-common/azure-common-%{version}.zip
Source1:        LICENSE.txt
BuildRequires:  %{python_module azure-nspkg >= 3.0.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
Requires:       python-azure-nspkg >= 3.0.0
Conflicts:      python-azure-sdk <= 2.0.0
%if 0%{?sle_version} >= 150400
Obsoletes:      python3-azure-common <= 1.1.28
%endif
BuildArch:      noarch

%python_subpackages

%description
This is the Microsoft Azure common code.

This package provides shared code by the Azure packages.

%prep
%setup -q -n azure-common-%{version}

%build
install -m 644 %{SOURCE1} %{_builddir}/azure-common-%{version}
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%{python_expand # delete common files
rm -rf %{buildroot}%{$python_sitelib}/azure/__init__.*
rm -rf %{buildroot}%{$python_sitelib}/azure/__pycache__
}

%files %{python_files}
%doc CHANGELOG.md README.md
%license LICENSE.txt
%{python_sitelib}/azure/common
%{python_sitelib}/azure_common-*.dist-info
%{python_sitelib}/azure/profiles

%changelog
* Fri May  3 2024 rjschwei@suse.com
- Change version setting of Obsoletes to <= to trigger python3
  binary removal since there was no source version bump
* Thu Apr  4 2024 adrian.glaubitz@suse.com
- Switch package to modern Python Stack on SLE-15
  + Use Python 3.11 on SLE-15 by default
  + Add Obsoletes for old python3 package on SLE-15
  + Drop support for older Python versions
- Switch build system from setuptools to pyproject.toml
  + Add python-pip and python-wheel to BuildRequires
  + Replace %%python_build with %%pyproject_wheel
  + Replace %%python_install with %%pyproject_install
  + Update name for dist directory in %%files section
- Drop setting default file attributes in %%files section
* Fri Feb  4 2022 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.1.28
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Tue May  4 2021 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.1.27
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Thu Nov 26 2020 rjschwei@suse.com
- Only build Python3 flavors for distributions 15 and greater
* Fri Nov 20 2020 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.1.26
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Fri Aug 28 2020 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.1.25
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Rename HISTORY.rst to CHANGELOG.md in %%files section
- Rename README.rst to README.md in %%files section
* Fri Jan 17 2020 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.1.24
  + For detailed information about changes see the
    HISTORY.txt file provided with this package
* Fri Oct  4 2019 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.1.23
  + For detailed information about changes see the
    HISTORY.txt file provided with this package
* Thu Apr 11 2019 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.1.18
  + For detailed information about changes see the
    HISTORY.txt file provided with this package
- Bump minimum version for namespace packages
  to 3.0.0 in BuildRequires and Requires
- Remove python-devel package from BuildRequires
- Run fdupes to hardlink duplicate files
  + Add fdupes to BuildRequires
  + Add %%fdupes invocation to %%install
* Mon Sep  3 2018 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.1.14
  + For detailed information about changes see the
    HISTORY.txt file provided with this package
* Tue Apr 10 2018 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.1.9
- Move LICENSE.txt from %%doc to %%license section
- Include profile files in Python directory
* Mon Jan 29 2018 adrian.glaubitz@suse.com
- Install HISTORY.rst into doc directory
* Wed Oct  4 2017 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.1.8
- Update Requires from setup.py
- Add namespace packages to BuildRequires
- Remove namespace files in %%install target
- Explicitly specify Python files of the package in %%files
* Thu Jul 13 2017 adrian.glaubitz@suse.com
- Stop providing namespace files
  + Drop ac_add-modules-to-setup.patch
  + Stop installing __init__.py into namespaces
* Tue Jun 27 2017 adrian.glaubitz@suse.com
- Initial build
  + Version 1.1.6
- Install __init__.py namespace files into all namespaces used by
  the Python Azure SDK (azure, azure-mgmt, azure-mgmt-datalake)
- Add patch to include namespace packages in setup.py
  + ac_add-modules-to-setup.patch
